@@ -9,7 +9,7 @@ package Org::Parser::Tiny;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-02-07'; # DATE
 our $DIST = 'Org-Parser-Tiny'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 sub new {
     my $class = shift;
@@ -237,7 +237,7 @@ sub tags {
     $_[0]{tags} || [];
 }
 
-sub headline_as_string {
+sub header_as_string {
     ($_[0]->{_str} //
          join('',
               "*" x $_[0]{level},
@@ -250,7 +250,7 @@ sub headline_as_string {
 }
 
 sub as_string {
-    $_[0]->headline_as_string .
+    $_[0]->header_as_string .
         $_[0]->{preamble} .
         $_[0]->children_as_string;
 }
@@ -270,7 +270,7 @@ Org::Parser::Tiny - Parse Org documents with as little code (and no non-core dep
 
 =head1 VERSION
 
-This document describes version 0.004 of Org::Parser::Tiny (from Perl distribution Org-Parser-Tiny), released on 2020-02-07.
+This document describes version 0.005 of Org::Parser::Tiny (from Perl distribution Org-Parser-Tiny), released on 2020-02-07.
 
 =head1 SYNOPSIS
 
@@ -433,9 +433,10 @@ will have its C<tags()> return C<< ["tag1","tag2"] >>, while this headline:
 
 will have its C<tags()> return C<< [] >>.
 
-=item * headline_as_string
+=item * header_as_string
 
-Headline line as string, without the preamble and children.
+First line of headline (the header) as string, without the preamble and
+children.
 
 =back
 
